instrumenttools.Marimba
=======================

.. abjad-lineage:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba

.. autoclass:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Marimba.Marimba.Marimba.__repr__
   :noindex:
